@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/ashpan/0.5.2")]
+#![doc(html_root_url = "https://docs.rs/ashpan/0.5.3")]
 //! This crate provides RAII helpers for [`ash`]. In particular:
 //!
 //! * [`Guarded`]/[`GuardedResource`] is essentially a
@@ -292,7 +292,7 @@ mod tests {
         }
 
         unsafe {
-            let entry = ash::Entry::new().unwrap();
+            let entry = ash::Entry::new();
             let instance = entry
                 .create_guarded_instance(unimplemented(), None)
                 .unwrap();
